summaryrefslogtreecommitdiff
path: root/sw/inc/anchoredobject.hxx
diff options
context:
space:
mode:
authorLuboš Luňák <l.lunak@suse.cz>2012-10-12 16:49:40 +0200
committerLuboš Luňák <l.lunak@suse.cz>2012-10-12 16:56:54 +0200
commit21d10c6f3266d4fac9c91f9d0fab529a6841b39e (patch)
treed4436c5d48e16d81518906f5337bd16ae1dec823 /sw/inc/anchoredobject.hxx
parent908794d36f489c60835bfa8a17ac6bd9c256c7df (diff)
mark lcl_ functions static or rename them if they are not local at all
http://lists.freedesktop.org/archives/libreoffice/2012-October/039639.html Change-Id: I21e12d6a4dfb9697d2346a4e564e96af0ad03f96
Diffstat (limited to 'sw/inc/anchoredobject.hxx')
-rw-r--r--sw/inc/anchoredobject.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/inc/anchoredobject.hxx b/sw/inc/anchoredobject.hxx
index 247717e12c91..0aad748dc17f 100644
--- a/sw/inc/anchoredobject.hxx
+++ b/sw/inc/anchoredobject.hxx
@@ -175,9 +175,9 @@ class SW_DLLPUBLIC SwAnchoredObject
void _CheckTopOfLine( const SwFmtAnchor& _rAnch,
const SwTxtFrm& _rAnchorCharFrm );
// method <lcl_HideObj(..)> sets needed data structure values for the
// object positioning
- friend bool lcl_HideObj( const SwTxtFrm& _rFrm,
+ friend bool sw_HideObj( const SwTxtFrm& _rFrm,
const RndStdIds _eAnchorType,
const xub_StrLen _nObjAnchorPos,
SwAnchoredObject* _pAnchoredObj );
@@ -175,9 +175,9 @@ class SW_DLLPUBLIC SwAnchoredObject
void _CheckTopOfLine( const SwFmtAnchor& _rAnch,
const SwTxtFrm& _rAnchorCharFrm );
- // method <lcl_HideObj(..)> sets needed data structure values for the
+ // method <sw_HideObj(..)> sets needed data structure values for the
// object positioning